@@ -13,10 +13,11 @@
  *******************************************************************************/
 package org.eclipse.compare.internal;
 
-import org.eclipse.swt.SWT;
-import org.eclipse.swt.widgets.*;
-
 import org.eclipse.compare.CompareViewerPane;
+import org.eclipse.swt.SWT;
+import org.eclipse.swt.widgets.Composite;
+import org.eclipse.swt.widgets.Control;
+import org.eclipse.swt.widgets.Tree;
 
 /**
  * Used whenever the input is null or no viewer can be found.
