@@ -10,6 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Stefan Dirix (sdirix@eclipsesource.com) - Bug 473847: Minimum E4 Compatibility of Compare
  *******************************************************************************/
 package org.eclipse.compare.internal;
 
@@ -23,6 +24,7 @@ import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.net.URL;
 import java.net.URLConnection;
+import java.text.MessageFormat;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.List;
@@ -60,6 +62,7 @@ import org.eclipse.core.runtime.IProgressMonitor;
 import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.ListenerList;
 import org.eclipse.core.runtime.MultiStatus;
+import org.eclipse.core.runtime.NullProgressMonitor;
 import org.eclipse.core.runtime.OperationCanceledException;
 import org.eclipse.core.runtime.Path;
 import org.eclipse.core.runtime.SafeRunner;
@@ -69,6 +72,7 @@ import org.eclipse.core.runtime.jobs.Job;
 import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.dialogs.ErrorDialog;
 import org.eclipse.jface.operation.IRunnableContext;
+import org.eclipse.jface.operation.IRunnableWithProgress;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.jface.text.IDocument;
 import org.eclipse.jface.text.IRegion;
@@ -77,9 +81,11 @@ import org.eclipse.jface.util.PropertyChangeEvent;
 import org.eclipse.jface.viewers.ISelection;
 import org.eclipse.jface.viewers.IStructuredSelection;
 import org.eclipse.swt.custom.BusyIndicator;
+import org.eclipse.swt.graphics.Image;
 import org.eclipse.swt.widgets.Composite;
 import org.eclipse.swt.widgets.Control;
 import org.eclipse.swt.widgets.Display;
+import org.eclipse.swt.widgets.Item;
 import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Widget;
 import org.eclipse.ui.IActionBars;
@@ -88,11 +94,10 @@ import org.eclipse.ui.IViewPart;
 import org.eclipse.ui.IWorkbenchPart;
 import org.eclipse.ui.IWorkbenchPartSite;
 import org.eclipse.ui.IWorkbenchSite;
+import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.progress.IWorkbenchSiteProgressService;
 import org.eclipse.ui.texteditor.IDocumentProvider;
 
-import com.ibm.icu.text.MessageFormat;
-
 /**
  * Convenience and utility methods.
  */
@@ -580,7 +585,7 @@ public class Utilities {
 	}
 
 	private static Map<IFile, Long> createModificationStampMap(List<IResource> files) {
-		Map<IFile, Long> map= new HashMap<IFile, Long>();
+		Map<IFile, Long> map= new HashMap<>();
 		for (IResource file : files) {
 			map.put((IFile) file, file.getModificationStamp());
 		}
@@ -813,7 +818,7 @@ public class Utilities {
 		for (Method method : methods) {
 			if (method.getName().equals("setReadTimeout")) { //$NON-NLS-1$
 				try {
-					method.invoke(connection, new Object[] {Integer.valueOf(timeout)});
+					method.invoke(connection, Integer.valueOf(timeout));
 					return true;
 				} catch (IllegalArgumentException | IllegalAccessException | InvocationTargetException e) {
 					// ignore
@@ -911,4 +916,62 @@ public class Utilities {
 		}
 		return buffer.toString();
 	}
+
+	/**
+	 * Executes the given runnable. Uses the {@link org.eclipse.ui.progress.IProgressService IProgressService}
+	 * if available.
+	 *
+	 * @param runnable
+	 *            The {@link IRunnableWithProgress} to execute.
+	 * @throws InvocationTargetException
+	 * @throws InterruptedException
+	 */
+	public static void executeRunnable(IRunnableWithProgress runnable) throws InvocationTargetException,
+			InterruptedException {
+		executeRunnable(runnable, true, true);
+	}
+
+	/**
+	 * Executes the given runnable. Uses the {@link org.eclipse.ui.progress.IProgressService IProgressService}
+	 * if available.
+	 *
+	 * @param runnable
+	 *            The {@link IRunnableWithProgress} to execute.
+	 * @param fork indicates whether to run within a separate thread.
+	 * @param cancelable indicates whether the operation shall be cancelable
+	 * @throws InvocationTargetException
+	 * @throws InterruptedException
+	 */
+	public static void executeRunnable(IRunnableWithProgress runnable, boolean fork, boolean cancelable) throws InvocationTargetException,
+			InterruptedException {
+		if (PlatformUI.isWorkbenchRunning()) {
+			PlatformUI.getWorkbench().getProgressService().run(fork, cancelable, runnable);
+		} else {
+			runnable.run(new NullProgressMonitor());
+		}
+	}
+
+	/**
+	 * Sets the menu image for the given {@link Item}. Uses the workbench shared image if available, otherwise
+	 * creates a new image and adds a dispose listener.
+	 *
+	 * @param item
+	 *            The {@link Item} for which the menu image is to be set.
+	 */
+	public static void setMenuImage(final Item item) {
+		final Image image;
+		if (PlatformUI.isWorkbenchRunning()) {
+			image = PlatformUI.getWorkbench().getSharedImages().getImage(
+			/* IWorkbenchGraphicConstants */"IMG_LCL_VIEW_MENU"); //$NON-NLS-1$
+		} else {
+			image = CompareUIPlugin.getImageDescriptor("elcl16/view_menu.png").createImage(); //$NON-NLS-1$
+			item.addDisposeListener(e -> {
+				Image img = item.getImage();
+				if ((img != null) && (!img.isDisposed())) {
+					img.dispose();
+				}
+			});
+		}
+		item.setImage(image);
+	}
 }
