@@ -51,8 +51,7 @@ public class PruneFolderVisitor implements ICVSResourceVisitor {
 		
 		// Visit the resources
 		Set prunableParents = new HashSet();
-		for (int i = 0; i < resources.length; i++) {
-			ICVSResource cvsResource = resources[i];
+		for (ICVSResource cvsResource : resources) {
 			// prune the resource and it's children when appropriate
 			cvsResource.accept(this);
 			// if the resource doesn't exists, attempt to prune it's parent
