@@ -26,9 +26,9 @@ import org.eclipse.team.internal.ccvs.core.util.SyncFileWriter;
  * @author Administrator
  *
  * To change this generated comment edit the template variable "typecomment":
- * Window>Preferences>Java>Templates.
+ * Window&gt;Preferences&gt;Java&gt;Templates.
  * To enable and disable the creation of type comments go to
- * Window>Preferences>Java>Code Generation.
+ * Window&gt;Preferences&gt;Java&gt;Code Generation.
  */
 public class TemplateHandler extends ResponseHandler {
 
@@ -66,18 +66,13 @@ public class TemplateHandler extends ResponseHandler {
 					IProgressMonitor monitor)
 					throws CVSException {
 
-					try {
-						// Transfer the contents
-						OutputStream out = new ByteArrayOutputStream();
-						try {
-							byte[] buffer = new byte[1024];
-							int read;
-							while ((read = stream.read(buffer)) >= 0) {
-								Policy.checkCanceled(monitor);
-								out.write(buffer, 0, read);
-							}
-						} finally {
-							out.close();
+					try ( // Transfer the contents
+							OutputStream out = new ByteArrayOutputStream()) {
+						byte[] buffer = new byte[1024];
+						int read;
+						while ((read = stream.read(buffer)) >= 0) {
+							Policy.checkCanceled(monitor);
+							out.write(buffer, 0, read);
 						}
 					} catch (IOException e) {
 						throw CVSException.wrapException(e); 
