@@ -75,7 +75,7 @@ public interface ICVSUIConstants {
 	public final String IMG_LINK_WITH_EDITOR_ENABLED = "elcl16/synced.gif"; //$NON-NLS-1$
 	
 	//history page toolbar
-	public final String IMG_FILTER_HISTORY = "elcl16/filter_history.gif";  //$NON-NLS-1$
+	public final String IMG_FILTER_HISTORY = "elcl16/filter_history.png"; //$NON-NLS-1$
 	
 	// wizards
 	public final String IMG_NEWLOCATION = "etool16/newlocation_wiz.gif"; //$NON-NLS-1$
