@@ -13,6 +13,8 @@
  *******************************************************************************/
 package org.eclipse.team.internal.ccvs.ui.console;
 
+import java.text.DateFormat;
+import java.text.SimpleDateFormat;
 import java.util.Date;
 
 import org.eclipse.core.runtime.*;
@@ -33,9 +35,6 @@ import org.eclipse.team.internal.ccvs.ui.*;
 import org.eclipse.ui.PlatformUI;
 import org.eclipse.ui.console.*;
 
-import com.ibm.icu.text.DateFormat;
-import com.ibm.icu.text.SimpleDateFormat;
-
 /**
  * Console that shows the output of CVS commands. It is shown as a page in the generic 
  * console view. It supports coloring for message, command, and error lines in addition
@@ -344,37 +343,56 @@ public class CVSOutputConsole extends MessageConsole implements IConsoleListener
 		String property = event.getProperty();
 		// colors
 		if (visible) {
-			if (property.equals(ICVSUIConstants.PREF_CONSOLE_COMMAND_COLOR)) {
-				Color newColor = createColor(CVSUIPlugin.getStandardDisplay(), ICVSUIConstants.PREF_CONSOLE_COMMAND_COLOR);
+			switch (property) {
+			case ICVSUIConstants.PREF_CONSOLE_COMMAND_COLOR: {
+				Color newColor = createColor(CVSUIPlugin.getStandardDisplay(),
+						ICVSUIConstants.PREF_CONSOLE_COMMAND_COLOR);
 				commandStream.setColor(newColor);
 				commandColor.dispose();
 				commandColor = newColor;
-			} else if (property.equals(ICVSUIConstants.PREF_CONSOLE_MESSAGE_COLOR)) {
-				Color newColor = createColor(CVSUIPlugin.getStandardDisplay(), ICVSUIConstants.PREF_CONSOLE_MESSAGE_COLOR);
+				return;
+			}
+			case ICVSUIConstants.PREF_CONSOLE_MESSAGE_COLOR: {
+				Color newColor = createColor(CVSUIPlugin.getStandardDisplay(),
+						ICVSUIConstants.PREF_CONSOLE_MESSAGE_COLOR);
 				messageStream.setColor(newColor);
 				messageColor.dispose();
 				messageColor = newColor;
-			} else if (property.equals(ICVSUIConstants.PREF_CONSOLE_ERROR_COLOR)) {
-				Color newColor = createColor(CVSUIPlugin.getStandardDisplay(), ICVSUIConstants.PREF_CONSOLE_ERROR_COLOR);
+				return;
+			}
+			case ICVSUIConstants.PREF_CONSOLE_ERROR_COLOR: {
+				Color newColor = createColor(CVSUIPlugin.getStandardDisplay(),
+						ICVSUIConstants.PREF_CONSOLE_ERROR_COLOR);
 				errorStream.setColor(newColor);
 				errorColor.dispose();
 				errorColor = newColor;
 				// font
-			} else if (property.equals(ICVSUIConstants.PREF_CONSOLE_FONT)) {
+				return;
+			}
+			case ICVSUIConstants.PREF_CONSOLE_FONT:
 				setFont(((FontRegistry) event.getSource()).get(ICVSUIConstants.PREF_CONSOLE_FONT));
+				return;
+			default:
+				break;
 			}
 		}
-		if (property.equals(ICVSUIConstants.PREF_CONSOLE_SHOW_ON_MESSAGE)) {
+		switch (property) {
+		case ICVSUIConstants.PREF_CONSOLE_SHOW_ON_MESSAGE:
 			Object value = event.getNewValue();
 			if (value instanceof String) {
 				showOnMessage = Boolean.valueOf((String) value).booleanValue();
 			} else {
 				showOnMessage = ((Boolean) value).booleanValue();
 			}
-		} else if(property.equals(ICVSUIConstants.PREF_CONSOLE_LIMIT_OUTPUT)) {
+			break;
+		case ICVSUIConstants.PREF_CONSOLE_LIMIT_OUTPUT:
 			initLimitOutput();
-		} else if(property.equals(ICVSUIConstants.PREF_CONSOLE_WRAP)) {
+			break;
+		case ICVSUIConstants.PREF_CONSOLE_WRAP:
 			initWrapSetting();
+			break;
+		default:
+			break;
 		}
 	}
 	
