@@ -149,8 +149,7 @@ public class RepositoryRoot extends PlatformObject {
 				ICVSRemoteResource[] folders = root.members(CVSTag.DEFAULT, true, monitor);
 				synchronized(modulesCacheLock) {
 					modulesCache = new HashMap();
-					for (int i = 0; i < folders.length; i++) {
-						ICVSRemoteResource resource = folders[i];
+					for (ICVSRemoteResource resource : folders) {
 						modulesCache.put(resource.getName(), resource);
 					}
 				}
@@ -223,9 +222,9 @@ public class RepositoryRoot extends PlatformObject {
 	}
 
 	private void addDateTags(CVSTag[] tags){
-		for(int i = 0; i < tags.length; i++){
-			if(tags[i].getType() == CVSTag.DATE){
-				dateTags.add(tags[i]);
+		for (CVSTag tag : tags) {
+			if (tag.getType() == CVSTag.DATE) {
+				dateTags.add(tag);
 			}
 		}
 	}
@@ -234,13 +233,13 @@ public class RepositoryRoot extends PlatformObject {
 		TagCacheEntry entry = getTagCacheEntryFor(remotePath, true);
 
 		// Store the tag with the appropriate ancestor
-		for (int i = 0; i < tags.length; i++) {
-			if (tags[i].getType() != CVSTag.DATE) {
+		for (CVSTag tag : tags) {
+			if (tag.getType() != CVSTag.DATE) {
 				Set parentTags = new HashSet();
 				addAllKnownTagsForParents(entry, parentTags);
-				if (!parentTags.contains(tags[i])) {
-					entry.getTags().add(tags[i]);
-					removeTagFromChildrenCacheEntries(entry, tags[i]);
+				if (!parentTags.contains(tag)) {
+					entry.getTags().add(tag);
+					removeTagFromChildrenCacheEntries(entry, tag);
 				}
 			}
 		}
@@ -281,8 +280,8 @@ public class RepositoryRoot extends PlatformObject {
 	private void removeDateTags(CVSTag[] tags) {		
 		if(dateTags.isEmpty())return;
 		// Store the tag with the appropriate ancestor
-		for (int i = 0; i < tags.length; i++) {
-			dateTags.remove(tags[i]);
+		for (CVSTag tag : tags) {
+			dateTags.remove(tag);
 		}
 	}
 
@@ -295,23 +294,23 @@ public class RepositoryRoot extends PlatformObject {
 
 		// remove tags from all parents of this path
 		entry = getKnownParentTagCacheEntryFor(remotePath);
-		for (int i = 0; i < tags.length; i++) {
-			if (entry.getTags().contains(tags[i])) {
-				entry.getTags().remove(tags[i]);
+		for (CVSTag tag : tags) {
+			if (entry.getTags().contains(tag)) {
+				entry.getTags().remove(tag);
 				continue;
 			}
 			TagCacheEntry currentEntry = entry;
 			while (currentEntry.parent != null) {
-				if (currentEntry.parent.getTags().contains(tags[i])) {
+				if (currentEntry.parent.getTags().contains(tag)) {
 					// remove tag from parent and add it to siblings
-					currentEntry.parent.getTags().remove(tags[i]);
+					currentEntry.parent.getTags().remove(tag);
 					Iterator siblingIterator = currentEntry.parent
 							.getChildrenIterator();
 					while (siblingIterator.hasNext()) {
 						TagCacheEntry sibling = (TagCacheEntry) siblingIterator
 								.next();
 						if (!sibling.equals(currentEntry)) {
-							sibling.getTags().add(tags[i]);
+							sibling.getTags().add(tag);
 						}
 					}
 					break;
@@ -339,8 +338,7 @@ public class RepositoryRoot extends PlatformObject {
 				return new String[0];
 			}
 			List<String> result = new ArrayList<>();
-			for (int i = 0; i < DEFAULT_AUTO_REFRESH_FILES.length; i++) {
-				String relativePath = DEFAULT_AUTO_REFRESH_FILES[i];
+			for (String relativePath : DEFAULT_AUTO_REFRESH_FILES) {
 				result.add(new Path(null, remotePath).append(relativePath).toString());
 			}
 			return result.toArray(new String[result.size()]);
@@ -360,8 +358,7 @@ public class RepositoryRoot extends PlatformObject {
 		// Check to see if the auto-refresh files are the default files
 		if (autoRefreshFiles.length == DEFAULT_AUTO_REFRESH_FILES.length) {
 			boolean isDefault = true;
-			for (int i = 0; i < DEFAULT_AUTO_REFRESH_FILES.length; i++) {
-				String filePath = DEFAULT_AUTO_REFRESH_FILES[i];
+			for (String filePath : DEFAULT_AUTO_REFRESH_FILES) {
 				if (!newFiles.contains(new Path(null, remotePath).append(filePath).toString())) {
 					isDefault = false;
 					break;
@@ -407,11 +404,10 @@ public class RepositoryRoot extends PlatformObject {
 				folder.fetchChildren(Policy.subMonitorFor(monitor, 10));
 				ICVSResource[] children = folder
 						.members(ICVSFolder.FOLDER_MEMBERS);
-				for (int i = 0; i < children.length; i++) {
-					tagsSet.addAll(Arrays.asList(refreshDefinedTags(
-							(ICVSFolder) children[i], recurse, Policy
-									.subMonitorFor(monitor,
-											100 / children.length))));
+				for (ICVSResource child : children) {
+					tagsSet.addAll(Arrays.asList(refreshDefinedTags((ICVSFolder) child, recurse, Policy
+							.subMonitorFor(monitor,
+									100 / children.length))));
 				}
 				tags = tagsSet.toArray(new CVSTag[tagsSet.size()]);
 			}
@@ -442,11 +438,9 @@ public class RepositoryRoot extends PlatformObject {
 		}
 		String[] keys = logEntries.getCachedFilePaths();
 		Set<CVSTag> tags = new HashSet<>();
-		for (int i = 0; i < keys.length; i++) {
-			String key = keys[i];
+		for (String key : keys) {
 			ILogEntry[] entries = logEntries.getLogEntries(key);
-			for (int j = 0; j < entries.length; j++) {
-				ILogEntry entry = entries[j];
+			for (ILogEntry entry : entries) {
 				tags.addAll(Arrays.asList(entry.getTags()));
 			}
 		}
@@ -469,8 +463,8 @@ public class RepositoryRoot extends PlatformObject {
 		try {
 			monitor.beginTask(null, filesToRefresh.length * 10); 
 			List<CVSTag> tags = new ArrayList<>();
-			for (int i = 0; i < filesToRefresh.length; i++) {
-				ICVSRemoteFile file = root.getRemoteFile(filesToRefresh[i], CVSTag.DEFAULT);
+			for (String f : filesToRefresh) {
+				ICVSRemoteFile file = root.getRemoteFile(f, CVSTag.DEFAULT);
 				try {
 					tags.addAll(Arrays.asList(fetchTags(file, Policy.subMonitorFor(monitor, 5))));
 				} catch (TeamException e) {
@@ -500,11 +494,9 @@ public class RepositoryRoot extends PlatformObject {
 	private CVSTag[] fetchTags(ICVSRemoteFile file, IProgressMonitor monitor) throws TeamException {
 		Set<CVSTag> tagSet = new HashSet<>();
 		ILogEntry[] entries = file.getLogEntries(monitor);
-		for (int j = 0; j < entries.length; j++) {
-			CVSTag[] tags = entries[j].getTags();
-			for (int k = 0; k < tags.length; k++) {
-				tagSet.add(tags[k]);
-			}
+		for (ILogEntry entry : entries) {
+			CVSTag[] tags = entry.getTags();
+			Collections.addAll(tagSet, tags);
 		}
 		return tagSet.toArray(new CVSTag[0]);
 	}
@@ -534,8 +526,7 @@ public class RepositoryRoot extends PlatformObject {
 	private TagCacheEntry getKnownParentTagCacheEntryFor(String remotePath) {
 		String[] segments = new Path(null, remotePath).segments();
 		TagCacheEntry currentTagCacheEntry = rootTagCacheEntry;
-		for (int i = 0; i < segments.length; i++) {
-			String segment = segments[i];
+		for (String segment : segments) {
 			if (currentTagCacheEntry.children.containsKey(segment)) {
 				currentTagCacheEntry = currentTagCacheEntry.children
 						.get(segment);
@@ -548,8 +539,8 @@ public class RepositoryRoot extends PlatformObject {
 
 	private void removeTagsFromChildrenCacheEntries(TagCacheEntry entry,
 			CVSTag[] tags) {
-		for (int i = 0; i < tags.length; i++) {
-			removeTagFromChildrenCacheEntries(entry, tags[i]);
+		for (CVSTag tag : tags) {
+			removeTagFromChildrenCacheEntries(entry, tag);
 		}
 		entry.getTags().removeAll(Arrays.asList(tags));
 		if (entry.isEmpty()) {
@@ -621,8 +612,7 @@ public class RepositoryRoot extends PlatformObject {
 		// Gather all the modules that have tags and/or auto-refresh files
 		// for each module, write the moduel, tags and auto-refresh files.
 		String[] paths = getKnownRemotePaths();
-		for (int i = 0; i < paths.length; i++) {
-			String path = paths[i];
+		for (String path : paths) {
 			attributes.clear();
 			String name = path;
 			if (isDefinedModuleName(path)) {
@@ -761,8 +751,7 @@ public class RepositoryRoot extends PlatformObject {
 			String path = folder.getRepositoryRelativePath();
 			CVSTag[] tags = getAllKnownTags(path);
 			CVSTag tag = folder.getTag();
-			for (int i = 0; i < tags.length; i++) {
-				CVSTag knownTag = tags[i];
+			for (CVSTag knownTag : tags) {
 				if (knownTag.equals(tag)) return true;
 			}
 		}
