@@ -18,14 +18,31 @@ import java.util.ArrayList;
 import java.util.List;
 
 import org.eclipse.core.resources.ResourcesPlugin;
-import org.eclipse.core.runtime.*;
-import org.eclipse.core.runtime.jobs.*;
+import org.eclipse.core.runtime.Assert;
+import org.eclipse.core.runtime.CoreException;
+import org.eclipse.core.runtime.IProgressMonitor;
+import org.eclipse.core.runtime.ISafeRunnable;
+import org.eclipse.core.runtime.IStatus;
+import org.eclipse.core.runtime.OperationCanceledException;
+import org.eclipse.core.runtime.ProgressMonitorWrapper;
+import org.eclipse.core.runtime.SafeRunner;
+import org.eclipse.core.runtime.Status;
+import org.eclipse.core.runtime.jobs.IJobChangeEvent;
+import org.eclipse.core.runtime.jobs.ILock;
+import org.eclipse.core.runtime.jobs.Job;
+import org.eclipse.core.runtime.jobs.JobChangeAdapter;
 import org.eclipse.jface.action.IAction;
 import org.eclipse.jface.dialogs.ErrorDialog;
 import org.eclipse.osgi.util.NLS;
 import org.eclipse.team.core.subscribers.Subscriber;
-import org.eclipse.team.internal.ui.*;
-import org.eclipse.team.ui.synchronize.*;
+import org.eclipse.team.internal.ui.Policy;
+import org.eclipse.team.internal.ui.TeamUIMessages;
+import org.eclipse.team.internal.ui.TeamUIPlugin;
+import org.eclipse.team.internal.ui.Utils;
+import org.eclipse.team.ui.synchronize.AbstractSynchronizeParticipant;
+import org.eclipse.team.ui.synchronize.ISynchronizeManager;
+import org.eclipse.team.ui.synchronize.ISynchronizeParticipant;
+import org.eclipse.team.ui.synchronize.SubscriberParticipant;
 import org.eclipse.ui.actions.ActionFactory;
 import org.eclipse.ui.progress.IProgressConstants;
 import org.eclipse.ui.progress.UIJob;
@@ -99,49 +116,49 @@ public abstract class RefreshParticipantJob extends Job {
 	 * that have occurred during the refresh
 	 */
 	private final class GotoActionWrapper extends WorkbenchAction {
-        private ActionFactory.IWorkbenchAction gotoAction;
-        private IStatus status;
-        @Override
+		private ActionFactory.IWorkbenchAction gotoAction;
+		private IStatus status;
+		@Override
 		public void run() {
-            if (status != null && !status.isOK()) {
-                ErrorDialog.openError(Utils.getShell(null), null, TeamUIMessages.RefreshSubscriberJob_3, status);
-            } else if(gotoAction != null) {
-        		gotoAction.run();
-        	}
-        }
-        @Override
+			if (status != null && !status.isOK()) {
+				ErrorDialog.openError(Utils.getShell(null), null, TeamUIMessages.RefreshSubscriberJob_3, status);
+			} else if(gotoAction != null) {
+				gotoAction.run();
+			}
+		}
+		@Override
 		public boolean isEnabled() {
-        	if(gotoAction != null) {
-        		return gotoAction.isEnabled();
-        	}
-        	return true;
-        }
-        @Override
+			if(gotoAction != null) {
+				return gotoAction.isEnabled();
+			}
+			return true;
+		}
+		@Override
 		public String getText() {
-        	if(gotoAction != null) {
-        		return gotoAction.getText();
-        	}
-        	return null;
-        }
-        @Override
+			if(gotoAction != null) {
+				return gotoAction.getText();
+			}
+			return null;
+		}
+		@Override
 		public String getToolTipText() {
-            if (status != null && !status.isOK()) {
-                return status.getMessage();
-            }
-        	if(gotoAction != null) {
-        		return gotoAction.getToolTipText();
-        	}
-        	return Utils.shortenText(SynchronizeView.MAX_NAME_LENGTH, RefreshParticipantJob.this.getName());
-        }
-        @Override
+			if (status != null && !status.isOK()) {
+				return status.getMessage();
+			}
+			if(gotoAction != null) {
+				return gotoAction.getToolTipText();
+			}
+			return Utils.shortenText(SynchronizeView.MAX_NAME_LENGTH, RefreshParticipantJob.this.getName());
+		}
+		@Override
 		public void dispose() {
-        	super.dispose();
-        	if(gotoAction != null) {
-        		gotoAction.dispose();
-        	}
-        }
-        public void setGotoAction(ActionFactory.IWorkbenchAction gotoAction) {
-            this.gotoAction = gotoAction;
+			super.dispose();
+			if(gotoAction != null) {
+				gotoAction.dispose();
+			}
+		}
+		public void setGotoAction(ActionFactory.IWorkbenchAction gotoAction) {
+			this.gotoAction = gotoAction;
 			setEnabled(isEnabled());
 			setToolTipText(getToolTipText());
 			gotoAction.addPropertyChangeListener(event -> {
@@ -150,13 +167,13 @@ public abstract class RefreshParticipantJob extends Job {
 					GotoActionWrapper.this.setEnabled(bool.booleanValue());
 				}
 			});
-        }
-        public void setStatus(IStatus status) {
-            this.status = status;
-        }
-    }
+		}
+		public void setStatus(IStatus status) {
+			this.status = status;
+		}
+	}
 
-    /**
+	/**
 	 * Notification for safely notifying listeners of refresh lifecycle.
 	 */
 	private abstract class Notification implements ISafeRunnable {
@@ -332,21 +349,21 @@ public abstract class RefreshParticipantJob extends Job {
 					}
 				}
 			} catch(CoreException e) {
-			    // Determine the status to be returned and the GOTO action
-			    status = e.getStatus();
-			    if (!isUser()) {
-		            // Use the GOTO action to show the error and return OK
-		            Object prop = getProperty(IProgressConstants.ACTION_PROPERTY);
-		            if (prop instanceof GotoActionWrapper) {
-		                GotoActionWrapper wrapper = (GotoActionWrapper)prop;
-		                wrapper.setStatus(e.getStatus());
-		                status = new Status(IStatus.OK, TeamUIPlugin.ID, IStatus.OK, e.getStatus().getMessage(), e);
-		            }
-			    }
-		        if (!isUser() && status.getSeverity() == IStatus.ERROR) {
-		            // Never prompt for errors on non-user jobs
-		            setProperty(IProgressConstants.NO_IMMEDIATE_ERROR_PROMPT_PROPERTY, Boolean.TRUE);
-		        }
+				// Determine the status to be returned and the GOTO action
+				status = e.getStatus();
+				if (!isUser()) {
+					// Use the GOTO action to show the error and return OK
+					Object prop = getProperty(IProgressConstants.ACTION_PROPERTY);
+					if (prop instanceof GotoActionWrapper) {
+						GotoActionWrapper wrapper = (GotoActionWrapper)prop;
+						wrapper.setStatus(e.getStatus());
+						status = new Status(IStatus.OK, TeamUIPlugin.ID, IStatus.OK, e.getStatus().getMessage(), e);
+					}
+				}
+				if (!isUser() && status.getSeverity() == IStatus.ERROR) {
+					// Never prompt for errors on non-user jobs
+					setProperty(IProgressConstants.NO_IMMEDIATE_ERROR_PROMPT_PROPERTY, Boolean.TRUE);
+				}
 			} finally {
 				event.setStopTime(System.currentTimeMillis());
 			}
@@ -366,7 +383,7 @@ public abstract class RefreshParticipantJob extends Job {
 			return event.getStatus();
 		} finally {
 			if (acquired) lock.release();
-            monitor.done();
+			monitor.done();
 		}
 	}
 
@@ -386,8 +403,7 @@ public abstract class RefreshParticipantJob extends Job {
 	private boolean isJobInFamilyRunning(Object family) {
 		Job[] jobs = Job.getJobManager().find(family);
 		if (jobs != null && jobs.length > 0) {
-			for (int i = 0; i < jobs.length; i++) {
-				Job job = jobs[i];
+			for (Job job : jobs) {
 				if (job.getState() != Job.NONE) {
 					return true;
 				}
@@ -405,12 +421,12 @@ public abstract class RefreshParticipantJob extends Job {
 			code = IRefreshEvent.STATUS_CHANGES;
 
 			int incomingChanges = getIncomingChangeCount();
-             String numIncomingChanges = incomingChanges==0 ? ""  //$NON-NLS-1$
-                 : NLS.bind(TeamUIMessages.RefreshCompleteDialog_incomingChanges, Integer.toString(incomingChanges));
+			String numIncomingChanges = incomingChanges==0 ? ""  //$NON-NLS-1$
+				: NLS.bind(TeamUIMessages.RefreshCompleteDialog_incomingChanges, Integer.toString(incomingChanges));
 
 			int outgoingChanges = getOutgoingChangeCount();
 			String numOutgoingChanges = outgoingChanges==0 ? ""  //$NON-NLS-1$
-                : NLS.bind(TeamUIMessages.RefreshCompleteDialog_outgoingChanges, Integer.toString(outgoingChanges));
+				: NLS.bind(TeamUIMessages.RefreshCompleteDialog_outgoingChanges, Integer.toString(outgoingChanges));
 
 			String sep = incomingChanges>0 && outgoingChanges>0 ? "; " : "";  //$NON-NLS-1$ //$NON-NLS-2$
 
@@ -419,9 +435,9 @@ public abstract class RefreshParticipantJob extends Job {
 				code = IRefreshEvent.STATUS_NEW_CHANGES;
 				String numNewChanges = Integer.toString(changeCount);
 				if (changeCount == 1) {
-				    text.append(NLS.bind(TeamUIMessages.RefreshCompleteDialog_newChangesSingular, (new Object[]{getName(), numNewChanges, numIncomingChanges, sep, numOutgoingChanges})));
+					text.append(NLS.bind(TeamUIMessages.RefreshCompleteDialog_newChangesSingular, (new Object[]{getName(), numNewChanges, numIncomingChanges, sep, numOutgoingChanges})));
 				} else {
-				    text.append(NLS.bind(TeamUIMessages.RefreshCompleteDialog_newChangesPlural, (new Object[]{getName(), numNewChanges, numIncomingChanges, sep, numOutgoingChanges})));
+					text.append(NLS.bind(TeamUIMessages.RefreshCompleteDialog_newChangesPlural, (new Object[]{getName(), numNewChanges, numIncomingChanges, sep, numOutgoingChanges})));
 				}
 			} else {
 				// Refreshed resources contain changes
@@ -470,7 +486,7 @@ public abstract class RefreshParticipantJob extends Job {
 								Job update = new UIJob("") { //$NON-NLS-1$
 									@Override
 									public IStatus runInUIThread(IProgressMonitor monitor) {
-									    runnable.run();
+										runnable.run();
 										return Status.OK_STATUS;
 									}
 								};
@@ -566,8 +582,7 @@ public abstract class RefreshParticipantJob extends Job {
 			listenerArray = listeners.toArray(new IRefreshSubscriberListener[listeners.size()]);
 		}
 		// Notify each listener in a safe manner (i.e. so their exceptions don't kill us)
-		for (int i = 0; i < listenerArray.length; i++) {
-			IRefreshSubscriberListener listener = listenerArray[i];
+		for (IRefreshSubscriberListener listener : listenerArray) {
 			Notification notification = new Notification() {
 				@Override
 				protected void notify(IRefreshSubscriberListener listener) {
