@@ -13,6 +13,8 @@
  *******************************************************************************/
 package org.eclipse.team.internal.ui.synchronize;
 
+import java.text.DateFormat;
+import java.text.SimpleDateFormat;
 import java.util.Collections;
 import java.util.Date;
 import java.util.HashMap;
@@ -49,9 +51,6 @@ import org.eclipse.team.internal.ui.TeamUIPlugin;
 import org.eclipse.team.internal.ui.Utils;
 import org.eclipse.team.ui.synchronize.ISynchronizeModelElement;
 
-import com.ibm.icu.text.DateFormat;
-import com.ibm.icu.text.SimpleDateFormat;
-
 /**
  * Handler that serializes the updating of a synchronize model provider.
  * All modifications to the synchronize model are performed in this
@@ -257,7 +256,7 @@ public class SynchronizeModelUpdateHandler extends BackgroundEventHandler implem
 		if (pendingLabelUpdates.isEmpty()) {
 			return false;
 		} else {
-			Utils.asyncExec((Runnable) () -> firePendingLabelUpdates(), getViewer());
+			Utils.asyncExec((Runnable) this::firePendingLabelUpdates, getViewer());
 			return true;
 		}
 	}
